@@ -32,11 +32,16 @@ class SentryClient(object):
         if conf.THRASHING_TIMEOUT and conf.THRASHING_LIMIT:
             cache_key = 'sentry:%s:%s' % (kwargs.get('class_name') or '', checksum)
             added = cache.add(cache_key, 1, conf.THRASHING_TIMEOUT)
-            try:
-                if not added and cache.incr(cache_key) > conf.THRASHING_LIMIT:
+            if not added:
+                try:
+                    thrash_count = cache.incr(cache_key)
+                except (KeyError, ValueError):
+                    # cache.incr can fail. Assume we aren't thrashing yet, and
+                    # if we are, hope that the next error has a successful
+                    # cache.incr call.
+                    thrash_count = 0
+                if thrash_count > conf.THRASHING_LIMIT:
                     return
-            except KeyError:
-                pass
 
         for filter_ in get_filters():
             kwargs = filter_(None).process(kwargs) or kwargs
@@ -163,7 +168,10 @@ class SentryClient(object):
             best_guess = None
             view = None
             for frame in iter_tb_frames(exc_traceback):
-                view = '.'.join([frame.f_globals['__name__'], frame.f_code.co_name])
+                try:
+                    view = '.'.join([frame.f_globals['__name__'], frame.f_code.co_name])
+                except:
+                    continue
                 if contains(modules, view):
                     if not (contains(conf.EXCLUDE_PATHS, view) and best_guess):
                         best_guess = view
@@ -176,8 +184,12 @@ class SentryClient(object):
                 kwargs['view'] = view
 
         data = kwargs.pop('data', {}) or {}
+        if hasattr(exc_type, '__class__'):
+            exc_module = exc_type.__class__.__module__
+        else:
+            exc_module = None
         data['__sentry__'] = {
-            'exc': map(transform, [exc_type.__class__.__module__, exc_value.args, frames]),
+            'exc': map(transform, [exc_module, exc_value.args, frames]),
         }
 
         if isinstance(exc_value, TemplateSyntaxError) and hasattr(exc_value, 'source'):
