@@ -4,6 +4,7 @@ import urllib2
 
 import django
 from django.conf import settings
+from django.utils.encoding import smart_unicode
 from django.utils.hashcompat import md5_constructor
 
 from sentry import conf
@@ -59,12 +60,25 @@ def varmap(func, var):
 def transform(value):
     # TODO: make this extendable
     # TODO: include some sane defaults, like UUID
+    # TODO: dont coerce strings to unicode, leave them as strings
     if isinstance(value, (tuple, list)):
         return [transform(o) for o in value]
     elif isinstance(value, dict):
         return dict((k, transform(v)) for k, v in value.iteritems())
-    elif not isinstance(value, (int, bool, basestring)) and value is not None:
-        return unicode(type(value))
+    elif isinstance(value, basestring):
+        value = force_unicode(value)
+    elif not isinstance(value, (int, bool)) and value is not None:
+        # XXX: we could do transform(repr(value)) here
+        return force_unicode(value)
+    return value
+
+def force_unicode(value):
+    try:
+        value = smart_unicode(value)
+    except (UnicodeEncodeError, UnicodeDecodeError):
+        value = '(Error decoding value)'
+    except Exception: # in some cases we get a different exception
+        value = smart_unicode(type(value))
     return value
 
 def get_installed_apps():
